@@ -140,12 +140,12 @@ struct
 
   external headerout_packetout : t -> (string * string) array -> Ogg.Stream.packet*Ogg.Stream.packet*Ogg.Stream.packet =  "ocaml_vorbis_analysis_headerout"
 
-  let headerout_packetout state tags =
-    let tags = Array.of_list (tags@[("ENCODER", encoder_tag)]) in
+  let headerout_packetout ?(encoder=encoder_tag) state tags =
+    let tags = Array.of_list (tags@[("ENCODER", encoder)]) in
       headerout_packetout state tags
 
-  let headerout state os tags =
-    let p1,p2,p3 = headerout_packetout state tags in
+  let headerout ?encoder state os tags =
+    let p1,p2,p3 = headerout_packetout ?encoder state tags in
     Ogg.Stream.put_packet os p1;
     Ogg.Stream.put_packet os p2;
     Ogg.Stream.put_packet os p3 
